@@ -1,26 +1,14 @@
-/***************************************************************************
-                          Ratio.cpp  -  source code of class Ratio
-                             -------------------
-    begin                : Tue Nov 27 16:40:42 CET 2001
-    copyright            : (C) 2001-2004 by Sebastian Stein
-    email                : seb.kde@hpfsc.de
+/*
+    Ratio.cpp  -  source code of class Ratio
+    SPDX-FileCopyrightText: 2001-2004 Sebastian Stein <seb.kde@hpfsc.de>
+    SPDX-FileCopyrightText: 2008 Tadeu Araujo <tadeu.araujo@ltia.fc.unesp.br>
+    SPDX-FileCopyrightText: 2008 Danilo Balzaque <danilo.balzaque@ltia.fc.unesp.br>
 
-    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
-    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "Ratio.h"
 
-
 #ifdef DEBUG
 #include <QDebug>
 #endif
